<?php
/**
 * Helper class which manages sending data
 *
 * @package GiroCheckout
 * @version $Revision: 24 $ / $Date: 2014-05-22 14:30:12 +0200 (Thu, 22 May 2014) $
 */

class GiroCheckout_SDK_curl_helper {

    /*
     * submits data by using curl to a given url
     *
     * @param String url where data has to be sent to
     * @param mixed[] array data which has to be sent
     * @return String body of the response
     */
    public static function submit($url, $params)
    {
        $ch = curl_init();

        curl_setopt($ch,CURLOPT_URL, $url);
        curl_setopt($ch,CURLOPT_POST, true);
        curl_setopt($ch,CURLOPT_POSTFIELDS, $params);
        curl_setopt($ch,CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HEADER, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Expect:'));

        $result = curl_exec($ch);
        curl_close($ch);

        return self::getHeaderAndBody($result);
    }

    /*
     * decodes a json string and returns an array
     *
     * @param String json string
     * @return mixed[] array of an parsed json string
     * @throws Exception if string is not a valid json string
     */
    public static function getJSONResponseToArray($string)
    {
        $json = json_decode($string,true);
        if(json_last_error() === JSON_ERROR_NONE) {
            return $json;
        }
        else {
            throw new Exception('Response is not a valid json string.');
        }
    }

    /*
     * strip header content
     *
     * @param String server response
     * @return mixed[] header, body of the server response. The header is parsed as an array.
     */
    private static function getHeaderAndBody($response) {

        $header = self::http_parse_headers(substr($response, 0, strpos($response,"\r\n\r\n")));
        $body = substr($response, strpos($response,"\r\n\r\n")+4);

        return array($header,$body);
    }

    /*
     * parses http header
     *
     * @param String header
     * @return mixed[] parsed header
     */
    private static function http_parse_headers($header)
    {
        $headers = array();
        $key = '';

        foreach(explode("\n", $header) as $i => $h) {
            $h = explode(':', $h, 2);

            if (isset($h[1]))
            {
                if (!isset($headers[$h[0]])) {
                    $headers[$h[0]] = trim($h[1]);
                }
                elseif (is_array($headers[$h[0]])) {
                    $headers[$h[0]] = array_merge($headers[$h[0]], array(trim($h[1])));
                }
                else {
                    $headers[$h[0]] = array_merge(array($headers[$h[0]]), array(trim($h[1])));
                }

                $key = $h[0];
            }
            else {
                if (substr($h[0], 0, 1) == "\t") {
                    $headers[$key] .= "\r\n\t".trim($h[0]);
                }
                elseif (!$key) {
                    $headers[0] = trim($h[0]);trim($h[0]);
                }
            }
        }

        return $headers;
    }
} 